;; Generated package description from csv-mode.el  -*- no-byte-compile: t -*-
(define-package "csv-mode" "1.18.0.20220323.163151" "Major mode for editing comma/char separated values" '((emacs "24.1") (cl-lib "0.5")) :commit "56ed871dc2feb9a12dce84a590ef9f049cc0405a" :url "https://elpa.gnu.org/packages/csv-mode.html" :authors '(("\"Francis J. Wright\"" . "F.J.Wright@qmul.ac.uk")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("convenience"))
